==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fArraylength.h <==
// class soot.coffi.Instruction_Arraylength

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class e6e5d9f0b7fdb913 soot_coffi_Instruction__5fArraylength
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fArraylength_H_
#define _JC_soot_coffi_Instruction__5fArraylength_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fArraylength$sub_refs	_jc_soot_coffi_Instruction__5fArraylength$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs	_jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$refs	_jc_soot_coffi_Instruction__5fArraylength$refs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$nonrefs	_jc_soot_coffi_Instruction__5fArraylength$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$object	_jc_soot_coffi_Instruction__5fArraylength$object;

typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vmethods	_jc_soot_coffi_Instruction__5fArraylength$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vtable	_jc_soot_coffi_Instruction__5fArraylength$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vtype	_jc_soot_coffi_Instruction__5fArraylength$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fArraylength$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fArraylength$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fArraylength$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fArraylength$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fArraylength$vmethods	soot_coffi_Instruction__5fArraylength;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fArraylength$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fArraylength$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fArraylength$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fArraylength$refs {
    _jc_soot_coffi_Instruction__5fArraylength$sub_refs	soot_coffi_Instruction__5fArraylength;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fArraylength$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs	soot_coffi_Instruction__5fArraylength;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fArraylength$object {
	_jc_soot_coffi_Instruction__5fArraylength$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fArraylength$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fArraylength$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fArraylength$vtype _jc_soot_coffi_Instruction__5fArraylength$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fArraylength, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fArraylength$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fArraylength_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fArraylength.h <==
// class soot.coffi.Instruction_Arraylength

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class e6e5d9f0b7fdb913 soot_coffi_Instruction__5fArraylength
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fArraylength_H_
#define _JC_soot_coffi_Instruction__5fArraylength_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fArraylength$sub_refs	_jc_soot_coffi_Instruction__5fArraylength$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs	_jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$refs	_jc_soot_coffi_Instruction__5fArraylength$refs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$nonrefs	_jc_soot_coffi_Instruction__5fArraylength$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fArraylength$object	_jc_soot_coffi_Instruction__5fArraylength$object;

typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vmethods	_jc_soot_coffi_Instruction__5fArraylength$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vtable	_jc_soot_coffi_Instruction__5fArraylength$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fArraylength$vtype	_jc_soot_coffi_Instruction__5fArraylength$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fArraylength$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fArraylength$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fArraylength$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fArraylength$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fArraylength$vmethods	soot_coffi_Instruction__5fArraylength;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fArraylength$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fArraylength$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fArraylength$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fArraylength$refs {
    _jc_soot_coffi_Instruction__5fArraylength$sub_refs	soot_coffi_Instruction__5fArraylength;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fArraylength$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fArraylength$sub_nonrefs	soot_coffi_Instruction__5fArraylength;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fArraylength$object {
	_jc_soot_coffi_Instruction__5fArraylength$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fArraylength$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fArraylength$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fArraylength$vtype _jc_soot_coffi_Instruction__5fArraylength$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fArraylength, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fArraylength$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fArraylength_H_ */
